==> Shiira2.0src.zip: Shiira2.0src/HMDTAppKit/trunk/source/HMDTAppKit/HMTabViewItem.h <==
/*
HMTabViewItem.h

Author: Makoto Kinoshita

Copyright 2004-2006 The Shiira Project. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted 
provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this list of conditions 
  and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice, this list of 
  conditions and the following disclaimer in the documentation and/or other materials provided 
  with the distribution.

THIS SOFTWARE IS PROVIDED BY THE SHIIRA PROJECT ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE SHIIRA PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/

#import <Cocoa/Cocoa.h>

@class HMTabView;
@class HMTabItemView;

typedef enum {
    HMTabViewItemNormal = 0, 
    HMTabViewItemOpening, 
    HMTabViewItemClosing, 
} HMTabViewItemStatus;

@interface HMTabViewItem : NSObject
{
    id                      _identifier;
    NSString*               _label;
    NSString*               _subLabel;
    NSAttributedString*     _attributedLabel;
    NSAttributedString*     _selectedAttributedLabel;
    NSAttributedString*     _noThumbnailAttributedLabel;
    
    NSImage*                _thumbnailImage;
    BOOL                    _showTitle;
    BOOL                    _isWorking;
    float                   _estimatedProgress;
    
    NSView*                 _view;
    BOOL                    _hasCloseButton;
    HMTabViewItemStatus     _status;
    
    HMTabView*              _tabView;
    HMTabItemView*          _tabItemView;
}

// Initialize
- (id)initWithIdentifier:(id)identifier;

// Label
- (NSString*)label;
- (NSAttributedString*)attributedLabel;
- (NSAttributedString*)selectedAttributedLabel;
- (NSAttributedString*)noThumbnailAttributedLabel;
- (void)setLabel:(NSString*)label;
- (NSString*)subLabel;
- (void)setSubLabel:(NSString*)subLabel;
- (NSImage*)thumbnailImage;
- (void)setThumbnailImage:(NSImage*)image;
- (BOOL)isWorking;
- (void)setWorking:(BOOL)working;
- (float)estimatedProgress;
- (void)setEstimatedProgress:(float)estimatedProgress;

// Identifier
- (id)identifier;
- (void)setIdentifier:(id)identifier;

// View
- (NSView*)view;
- (void)setView:(NSView*)view;

// Status
- (HMTabViewItemStatus)status;
- (void)setStatus:(HMTabViewItemStatus)status;

// Parent tab view
- (HMTabView*)tabView;
- (void)setTabView:(HMTabView*)tabView;
- (HMTabItemView*)tabItemView;
- (void)setTabItemView:(HMTabItemView*)tabItemView;

// Close button
- (BOOL)hasCloseButton;
- (void)setHasCloseButton:(BOOL)hasCloseButton;

@end

==> Shiira2.2src.zip: Shiira2.2src/HMDTAppKit/trunk/source/HMDTAppKit/HMTabViewItem.h <==
/*
HMTabViewItem.h

Author: Makoto Kinoshita

Copyright 2004-2006 The Shiira Project. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted 
provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this list of conditions 
  and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice, this list of 
  conditions and the following disclaimer in the documentation and/or other materials provided 
  with the distribution.

THIS SOFTWARE IS PROVIDED BY THE SHIIRA PROJECT ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE SHIIRA PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/

#import <Cocoa/Cocoa.h>

@class HMTabView;
@class HMTabItemView;

typedef enum {
    HMTabViewItemNormal = 0, 
    HMTabViewItemOpening, 
    HMTabViewItemClosing, 
} HMTabViewItemStatus;

@interface HMTabViewItem : NSObject
{
    id                      _identifier;
    NSString*               _label;
    NSString*               _subLabel;
    NSAttributedString*     _attributedLabel;
    NSAttributedString*     _selectedAttributedLabel;
    NSAttributedString*     _noThumbnailAttributedLabel;
    
    NSImage*                _thumbnailImage;
    BOOL                    _showTitle;
    BOOL                    _isWorking;
    float                   _estimatedProgress;
    
    NSView*                 _view;
    BOOL                    _hasCloseButton;
    HMTabViewItemStatus     _status;
    
    HMTabView*              _tabView;
    HMTabItemView*          _tabItemView;
    NSTabViewItem*          _nsTabViewItem;
}

// Initialize
- (id)initWithIdentifier:(id)identifier;

// Label
- (NSString*)label;
- (NSAttributedString*)attributedLabel;
- (NSAttributedString*)selectedAttributedLabel;
- (NSAttributedString*)noThumbnailAttributedLabel;
- (void)setLabel:(NSString*)label;
- (NSString*)subLabel;
- (void)setSubLabel:(NSString*)subLabel;
- (NSImage*)thumbnailImage;
- (void)setThumbnailImage:(NSImage*)image;
- (BOOL)isWorking;
- (void)setWorking:(BOOL)working;
- (float)estimatedProgress;
- (void)setEstimatedProgress:(float)estimatedProgress;

// Identifier
- (id)identifier;
- (void)setIdentifier:(id)identifier;

// View
- (NSView*)view;
- (void)setView:(NSView*)view;

// Status
- (HMTabViewItemStatus)status;
- (void)setStatus:(HMTabViewItemStatus)status;

// Parent tab view
- (HMTabView*)tabView;
- (void)setTabView:(HMTabView*)tabView;
- (HMTabItemView*)tabItemView;
- (void)setTabItemView:(HMTabItemView*)tabItemView;
- (NSTabViewItem*)nsTabViewItem;
- (void)setNSTabViewItem:(NSTabViewItem*)nsTabViewItem;

// Close button
- (BOOL)hasCloseButton;
- (void)setHasCloseButton:(BOOL)hasCloseButton;

@end
